@@ -1,4 +1,4 @@
-"""Falcon Scheduled Reports API Interface Class
+"""Falcon Scheduled Reports API Interface Class.
 
  _______                        __ _______ __        __ __
 |   _   .----.-----.--.--.--.--|  |   _   |  |_.----|__|  |--.-----.
@@ -36,12 +36,13 @@ OTHER DEALINGS IN THE SOFTWARE.
 For more information, please refer to <https://unlicense.org>
 """
 from ._util import force_default, process_service_request, handle_single_argument
+from ._payload import reports_payload
 from ._service_class import ServiceClass
 from ._endpoint._scheduled_reports import _scheduled_reports_endpoints as Endpoints
 
 
 class ScheduledReports(ServiceClass):
-    """The only requirement to instantiate an instance of this class is one of the following:
+    """The only requirement to instantiate an instance of this class is one of the following.
 
     - a valid client_id and client_secret provided as keywords.
     - a credential dictionary with client_id and client_secret containing valid API credentials
@@ -52,6 +53,40 @@ class ScheduledReports(ServiceClass):
     - a previously-authenticated instance of the authentication service class (oauth2.py)
     - a valid token provided by the authentication service class (oauth2.py)
     """
+
+    @force_default(defaults=["body"], default_types=["dict"])
+    def launch(self: object, *args, body: dict = None, **kwargs) -> dict:
+        """Launch scheduled report executions for the provided ID(s).
+
+        Keyword arguments:
+        body -- full body payload, not required if keywords are used.
+                [
+                    {
+                        "id": "string"
+                    }
+                ]
+        ids -- ID of the report to launch. String or list of strings.
+
+        Arguments: When not specified, the first argument to this method is assumed to be 'ids'.
+                   All others are ignored.
+
+        Returns: dict object containing API response.
+
+        HTTP Method: POST
+
+        Swagger URL
+        https://assets.falcon.crowdstrike.com/support/api/swagger.html#/scheduled-reports/scheduled-reports.launch
+        """
+        if not body:
+            body = reports_payload(passed_arguments=args, passed_keywords=kwargs)
+
+        return process_service_request(
+            calling_object=self,
+            endpoints=Endpoints,
+            operation_id="scheduled_reports_launch",
+            body=body
+            )
+
     @force_default(defaults=["parameters"], default_types=["dict"])
     def get_reports(self: object, *args, parameters: dict = None, **kwargs) -> dict:
         """Retrieve scheduled reports for the provided report IDs.
@@ -80,11 +115,12 @@ class ScheduledReports(ServiceClass):
 
     @force_default(defaults=["parameters"], default_types=["dict"])
     def query_reports(self: object, parameters: dict = None, **kwargs) -> dict:
-        """Find all report IDs matching the query with filter
+        """Find all report IDs matching the query with filter.
 
         Keyword arguments:
         filter -- FQL query specifying the filter parameters.
-                  Filter term criteria: type, trigger_reference, recipients, user_uuid, cid, trigger_params.metadata.
+                  Filter term criteria: type, trigger_reference, recipients, user_uuid,
+                                        cid, trigger_params.metadata.
                   Filter range criteria: created_on, modified_on;
                     use any common date format, such as '2010-05-15T14:55:21.892315096Z'.
         limit -- The maximum number of ids to return.
@@ -92,7 +128,8 @@ class ScheduledReports(ServiceClass):
         parameters - full parameters payload, not required if using other keywords.
         q -- Match query criteria, which includes all the filter string fields.
         sort -- The property to sort by. FQL syntax. (e.g. created_on.asc, last_updated_on.desc)
-                Possible sort fields: created_on, last_updated_on, last_execution_on, next_execution_on
+                Possible sort fields: created_on, last_updated_on, last_execution_on,
+                                      next_execution_on
 
         This method only supports keywords for providing arguments.
 
@@ -115,3 +152,4 @@ class ScheduledReports(ServiceClass):
     # API and are defined here for ease of use purposes
     scheduled_reports_get = get_reports
     scheduled_reports_query = query_reports
+    scheduled_reports_launch = launch
